@@ -63,12 +63,12 @@ class Settings:
     references: set[str]
     tolerances: dict[str, Tolerances]
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         """Coerce the attributes types."""
         self.marks = set(self.marks)
         self.references = set(self.references)
         for key, value in self.tolerances.copy().items():
-            self.tolerances[key] = Tolerances(**value)
+            self.tolerances[key] = Tolerances(**value)  # type:ignore
 
     @classmethod
     def from_local_file(cls, path_global: Path, path_local: Path) -> Settings:
